@@ -1,14 +1,16 @@
 package App::CompleteCLIs;
 
-our $DATE = '2021-05-09'; # DATE
-our $VERSION = '0.150'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-09-09'; # DATE
+our $DIST = 'App-CompleteCLIs'; # DIST
+our $VERSION = '0.151'; # VERSION
+
 1;
-# ABSTRACT: CLI wrappers for complete_*() functions
+# ABSTRACT: CLI front-end for the complete_*() functions from Complete::* modules
 
 __END__
 
@@ -18,11 +20,11 @@ __END__
 
 =head1 NAME
 
-App::CompleteCLIs - CLI wrappers for complete_*() functions
+App::CompleteCLIs - CLI front-end for the complete_*() functions from Complete::* modules
 
 =head1 VERSION
 
-This document describes version 0.150 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2021-05-09.
+This document describes version 0.151 of App::CompleteCLIs (from Perl distribution App-CompleteCLIs), released on 2022-09-09.
 
 =head1 SYNOPSIS
 
@@ -114,6 +116,8 @@ functions on the command-line.
 
 =item * L<complete-program>
 
+=item * L<complete-random-string>
+
 =item * L<complete-rclone-remote>
 
 =item * L<complete-regexp-pattern-module>
@@ -156,14 +160,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Comple
 
 Source repository is at L<https://github.com/perlancar/perl-App-CompleteCLIs>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CompleteCLIs>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Complete>
@@ -174,11 +170,37 @@ C<Complete::*> modules
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021, 2020, 2019, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CompleteCLIs>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
